@@ -166,7 +166,6 @@ m.fsWBY1c <- BYlogreg(x0=X1c, y=y.fs,
 
 ###-------- Gamma ------------
 
-
 ## Realistic "data" {from help(glmrob)}:
 mu <- c(122.131, 53.0979, 39.9039, 33.9232, 28.007,
         24.923, 21.5747, 19.6971, 18.4516)
@@ -176,22 +175,22 @@ Vmu <- c(14915.9, 2819.38, 1592.32, 1150.78, 784.39,
          621.156, 465.467, 387.978, 340.462)
 Hp2  <- robustbase:::Huberprop2
 ## Hp2. <- robustbase:::Huberprop2.
-phis <- 2^(-70:-1)
+
+## was: phis <- 2^(-70:-1)  -- but that was *not* reliable (on 32-bit e.g.)
+phis <- 2^(-42:-1)
 H1 <- sapply(phis, function(phi)
     Hp2(phi, ns.resid=ns.resid, mu=mu, Vmu=Vmu, tcc = 1.345))
 ## H2 <- sapply(phis, function(phi)
 ##     Hp2.(phi, ns.resid=ns.resid, mu=mu, Vmu=Vmu, tcc = 1.345))
-H2 <- c(18.0856, 30.1906, Inf, Inf, 30.1906, 30.1906, 30.1906, Inf,
-        30.1906, 30.1906, Inf, 18.0856, 18.0856, 30.1906, 1.82958e+112,
-        18.0856, 18.0856, 5.98061, 215133000, 18.0897, 18.3073, 30.1906,
-        12.072, 7.96789, 9.69334, 10.1877, 9.81119, 9.96391, 9.91741,
+dput(signif(H1))
+H2 <- c(9.91741,
         9.88674, 9.89438, 9.88674, 9.88961, 9.88961, 9.88961, 9.88984,
         9.88973, 9.88964, 9.8897, 9.88975, 9.88976, 9.88975, 9.88974,
         9.88974, 9.88974, 9.88974, 9.88974, 9.88974, 9.88974, 9.88974,
         9.88975, 9.88975, 9.88975, 9.33161, 8.70618, 8.39347, 8.23714,
         8.15902, 8.12006, 7.16275, 3.38703, -0.0879886, -2.3322, -4.16929,
         -5.26821, -5.80526, -6.04822, -6.11538, -6.02613, -5.66718)
-          all.equal(H1,H2, tolerance = 0) # -> see 1.74e-6
+          all.equal(H1,H2, tolerance = 0) # -> see 8.869e-7
 stopifnot(all.equal(H1,H2, tolerance = 1e-5))
 
 if(dev.interactive(TRUE)) # shows that phi < 1e-12 is doubtful
